@@ -1,7 +1,3 @@
-//! Daml JSON <> GRPC Bridge.
-//!
-//! Provides a library and executable for bridging the JSON and GRPC Daml ledger APIs.
-
 #![warn(clippy::all, clippy::pedantic, clippy::nursery, rust_2018_idioms)]
 #![allow(
     clippy::module_name_repetitions,
@@ -13,7 +9,10 @@
 #![forbid(unsafe_code)]
 #![doc(html_favicon_url = "https://docs.daml.com/_static/images/favicon/favicon-32x32.png")]
 #![doc(html_logo_url = "https://docs.daml.com/_static/images/DAML_Logo_Blue.svg")]
-#![doc(html_root_url = "https://docs.rs/daml-bridge/0.1.1")]
+#![doc(html_root_url = "https://docs.rs/daml-bridge/0.2.1")]
+// importing the crate README as the rust doc breaks the link to the LICENCE file.
+#![allow(rustdoc::broken_intra_doc_links)]
+#![doc = include_str!("../README.md")]
 
 mod aliases;
 mod bridge;
